/* -------------------------------------------------------------------
    File "MagSta_a_3D.pro"
    Magnetostatics - Magnetic vector potential a formulation (3D)
    -------------------------------------------------------------------
    I N P U T
    ---------
    GlobalGroup : (Extension _Mag is for Magnetic problem)
    -----------
    Domain_Mag Whole magnetic domain
    DomainS_Mag Inductor regions (Source)
    Function :
    --------
    nu[] Magnetic reluctivity
    Constraint :
    ----------
*/
Group {
    DefineGroup[ Domain_Mag, DomainS_Mag ];
}

Function {
    DefineFunction[ nu ];
}

FunctionSpace {
    // Magnetic vector potential a (b = curl a)
    { Name Hcurl_a_Mag_3D; Type Form1;
      BasisFunction {
        // a = a s
        //  e   e
        { Name se; NameOfCoef ae; Function BF_Edge;
          Support Domain_Mag; Entity EdgesOf[ All ]; }
    }
    Constraint {
        { NameOfCoef ae; EntityType EdgesOf;
            NameOfConstraint MagneticVectorPotential_3D; }
        { NameOfCoef ae; EntityType EdgesOfTreeIn; EntitySubType StartingOn; 
            NameOfConstraint Gauge; }
        }
    }

}

Formulation {
    { Name Magnetostatics_a_3D; Type FemEquation;
      Quantity {
        { Name a ; Type Local; NameOfSpace Hcurl_a_Mag_3D; }
      }
      Equation {
            Galerkin { [ nu[] * Dof{Curl a} , {Curl a} ]; In Domain_Mag;
                        Jacobian Vol; Integration CurlCurl; }
            Galerkin { [ - js[] , {a} ]; In DomainS_Mag;
                        Jacobian Vol; Integration CurlCurl; }
      }
    }
}

Resolution {
    {   Name MagSta_a_3D;
        System {
            { Name Sys_Mag; NameOfFormulation Magnetostatics_a_3D; }
        }
        Operation {
            Generate[Sys_Mag]; Solve[Sys_Mag]; SaveSolution[Sys_Mag];
        }
    }
}

PostProcessing {
    {   Name MagSta_a_3D; NameOfFormulation Magnetostatics_a_3D;
        Quantity {
            { Name a;
                Value {
                    Local { [ {a} ]; In Domain_Mag; Jacobian Vol; }
                }
            }
            { Name b;
                Value {
                    Local { [ {d a} ]; In Domain_Mag; Jacobian Vol; }
                }
            }
            { Name h;
                Value {
                    Local { [ nu[] * {d a} ]; In Domain_Mag; Jacobian Vol; }
                }
            }
            { Name js;
                Value {
                    Local { [js[]] ; In DomainS_Mag; Jacobian Vol; }
                }
            }
                
        }
    }
}
