// Fichier "OneTooth.pro"
// Magntostatique

Include "OneTooth-dat.pro";

Group {
    Air          = #AIR;
    Core         = #CORE;
    Ind          = #COIL;
    Plate        = #PLATE;
    
	SurfaceGe0   = #CUT_SYMMETRY ;
    SurfaceGInf  = #AIR_INF;
    SkinCore     = #SKIN_CORE;
    SkinPlate    = #SKIN_PLATE;

    DomainS_Mag = Region[{Ind}];
    Domain_Mag  = Region[{Core, Air, Ind, Plate}];
}

Function {
    mu0 = 4.e-7 * Pi;  
    murSteel = 100.;
    nu [ Region[{Air, Ind}] ] = 1. / mu0;
    nu [ Region[{Core}]] = 1. / (murSteel*mu0);
    nu [ Region[{Plate}]] = 1. / (murSteel*mu0);
    
    Sc          = th_coil*ly_coil;  //cross section of coil
    Ns          = 100;		//Number of turns of the inductor Ind
    Val_Current = 1.0;		//current in the inductor

    //calculation of current vectors
    xc = 0.;  // center of the coil
    zc = 0.;   // center of the coil
    
    js[ Ind ] = Ns/Sc * Val_Current * Vector[-Sin[Atan2[Z[]-zc,X[]-xc]],
											  0.,
											  Cos[Atan2[Z[]-zc,X[]-xc]]] ;
}

Constraint {
    { Name MagneticVectorPotential_3D; Type Assign;
        Case {
            { Region SurfaceGInf ; Value 0.; }
			{ Region SurfaceGe0 ; Value 0.; }
        }
    }

    { Name Gauge; Type Assign;
        Case {
          //{ Region Domain_Mag; SubRegion #{SkinCore, SkinPlate}; Value 0.; }
        }
    }

}

Jacobian {
    { Name Vol ;
        Case { 
                { Region All ; Jacobian Vol ; }
        }
    }
}

Integration {
    { Name CurlCurl ;
        Case { {Type Gauss ;
            Case {  
                    { GeoElement Triangle ; NumberOfPoints 4 ; }
                    { GeoElement Tetrahedron ; NumberOfPoints 4 ; }
                 }
            }
        }
    }
}

Include "Magsta_a_3D.pro"

PostOperation {
    { Name Map_a; NameOfPostProcessing MagSta_a_3D;
        Operation {
			//Print[ a, OnElementsOf Domain_Mag, File "Magsta_a_3D_a.pos" ];
            Print[ b,  OnElementsOf Domain_Mag, File "Magsta_a_3D_b.pos" ];
            Print[ js, OnElementsOf DomainS_Mag, File "Magsta_a_3D_js.pos" ];
        }
    }
}

// EOF
